summaryrefslogtreecommitdiffhomepage
path: root/projects/Notepad++
diff options
context:
space:
mode:
authorDane Madsen <[email protected]>2023-05-21 19:33:47 +1000
committerGitHub <[email protected]>2023-05-21 11:33:47 +0200
commite96dc46d38fcc73cc278ef7a1ad95ce63c6ce989 (patch)
treedce80cf3f5d6b9cff2486da6e0f0e3ea6df02f01 /projects/Notepad++
parent1b4634702ca9f1e76477833618ccfea9093f03e5 (diff)
downloadraylib-e96dc46d38fcc73cc278ef7a1ad95ce63c6ce989.tar.gz
raylib-e96dc46d38fcc73cc278ef7a1ad95ce63c6ce989.zip
Replaced GenImageGradientH and GenImageGradientV with GenImageLinearGradient (#3074)
* Replaced GenImageGradientH and GenImageGradientV with GenImageLinearGradient * renamed GenImageLinearGradient to GenImageGradientLinear
Diffstat (limited to 'projects/Notepad++')
-rw-r--r--projects/Notepad++/raylib_npp_parser/raylib_npp.xml17
-rw-r--r--projects/Notepad++/raylib_npp_parser/raylib_to_parse.h3
2 files changed, 6 insertions, 14 deletions
diff --git a/projects/Notepad++/raylib_npp_parser/raylib_npp.xml b/projects/Notepad++/raylib_npp_parser/raylib_npp.xml
index e764a1b6..890501f2 100644
--- a/projects/Notepad++/raylib_npp_parser/raylib_npp.xml
+++ b/projects/Notepad++/raylib_npp_parser/raylib_npp.xml
@@ -1378,20 +1378,13 @@
<Param name="Color color" />
</Overload>
</KeyWord>
- <KeyWord name="GenImageGradientV" func="yes">
- <Overload retVal="Image" descr="Generate image: vertical gradient">
+ <KeyWord name="GenImageGradientLinear" func="yes">
+ <Overload retVal="Image" descr="Generate image: linear gradient">
<Param name="int width" />
<Param name="int height" />
- <Param name="Color top" />
- <Param name="Color bottom" />
- </Overload>
- </KeyWord>
- <KeyWord name="GenImageGradientH" func="yes">
- <Overload retVal="Image" descr="Generate image: horizontal gradient">
- <Param name="int width" />
- <Param name="int height" />
- <Param name="Color left" />
- <Param name="Color right" />
+ <Param name="int direction" />
+ <Param name="Color start" />
+ <Param name="Color end" />
</Overload>
</KeyWord>
<KeyWord name="GenImageGradientRadial" func="yes">
diff --git a/projects/Notepad++/raylib_npp_parser/raylib_to_parse.h b/projects/Notepad++/raylib_npp_parser/raylib_to_parse.h
index 96732e31..3f845013 100644
--- a/projects/Notepad++/raylib_npp_parser/raylib_to_parse.h
+++ b/projects/Notepad++/raylib_npp_parser/raylib_to_parse.h
@@ -317,8 +317,7 @@ RLAPI bool ExportImageAsCode(Image image, const char *fileName);
// Image generation functions
RLAPI Image GenImageColor(int width, int height, Color color); // Generate image: plain color
-RLAPI Image GenImageGradientV(int width, int height, Color top, Color bottom); // Generate image: vertical gradient
-RLAPI Image GenImageGradientH(int width, int height, Color left, Color right); // Generate image: horizontal gradient
+RLAPI Image GenImageGradientLinear(int width, int height, int direction, Color start, Color end); // Generate image: linear gradient
RLAPI Image GenImageGradientRadial(int width, int height, float density, Color inner, Color outer); // Generate image: radial gradient
RLAPI Image GenImageChecked(int width, int height, int checksX, int checksY, Color col1, Color col2); // Generate image: checked
RLAPI Image GenImageWhiteNoise(int width, int height, float factor); // Generate image: white noise